*******************
Authors and Credits
*******************

Astropy Project Coordinators
============================

* Tom Aldcroft
* Kelle Cruz
* Thomas Robitaille
* Erik Tollerud


Core Package Contributors
=========================

* Aaron Meisner
* Aarya Patil
* Abhinuv Nitin Pitale
* Abigail Stevens
* Adam Ginsburg
* Adele Plunkett
* Aditya Sharma
* Adrian Price-Whelan
* Akash Deshpande
* Al Niessner
* Albert Y. Shih
* Aleh Khvalko
* Alex Conley
* Alex Drlica-Wagner
* Alex Hagen
* Alex Rudy
* Alex de la Vega
* Alexander Bakanov
* Alexandre Beelen
* Amit Kumar
* Ana Posses
* Anany Shrey Jain
* Anchit Jain
* Andreas Baumbach
* Andrej Rode
* Andrew Hearin
* Aniket Kulkarni
* Aniket Sanghi
* Anirudh Katipally
* Anne Archibald
* Antetokounpo
* Anthony Horton
* Antony Lee
* Arfon Smith
* Arie Kurniawan
* Arne de Laat
* Arthur Eigenbrot
* Asish Panda
* Asra Nizami
* Austen Groener
* Axel Donath
* Azalee Bostroem
* Bastian Beischer
* Ben Greiner
* Benjamin Alan Weaver
* Benjamin Roulston
* Benjamin Winkel
* Bernardo Sulzbach
* Bernie Simon
* Bhavya Khandelwal
* Bili Dong
* Bogdan Nicula
* Bojan Nikolic
* Brett Morris
* Brian Soto
* Brigitta Sipőcz
* Bruce Merry
* Bruno Oliveira
* Bryce Kalmbach
* Bryce Nordgren
* Carl Osterwisch
* Carl Schaffer
* Chiara Marmo
* Chris Beaumont
* Chris Hanley
* Chris Osborne
* Chris Simpson
* Christian Clauss
* Christian Hettlage
* Christoph Deil
* Christoph Gohlke
* Christopher Bonnett
* Chun Ly
* Clara Brasseur
* Clare Shanahan
* Clément Robert
* Cristian Ardelean
* Curtis McCully
* Dan Foreman-Mackey
* Dan P. Cunningham
* Dan Ryan
* Dan Taranu
* Daniel Bell
* Daniel D'Avella
* Daniel Datsev
* Daniel Lenz
* Daniel Ruschel Dutra
* Danny Goldstein
* Daria Cara
* David Kirkby
* David M. Palmer
* David Pérez-Suárez
* David Shiga
* David Shupe
* David Stansby
* Demitri Muna
* Derek Homeier
* Devin Crichton
* Diego Alonso
* Dominik Klaes
* Doug Burke
* Drew Leonard
* Duncan Macleod
* Dylan Gregersen
* Ed Slavich
* Edward Betts
* Eero Vaher
* Eli Bressert
* Elijah Bernstein-Cooper
* Eloy Salinas
* Emily Deibert
* Emma Hogan
* Eric Depagne
* Eric Jeschke
* Eric Koch
* E. Madison Bray
* Erik Tollerud
* Erin Allard
* Esteban Pardo Sánchez
* Even Rouault
* Evert Rol
* Felix Yan
* Francesco Biscani
* Francesco Montanari
* Francesco Montesano
* Frédéric Chapoton
* Frédéric Grollier
* Gabriel Brammer
* Gabriel Perren
* Geert Barentsen
* George Galvin
* Georgiana Ogrean
* Gerrit Schellenberger
* Giang Nguyen
* Giorgio Calderone
* Graham Kanarek
* Grant Jenks
* Gregory Dubois-Felsmann
* Gregory Simonian
* Griffin Hosseinzadeh
* Gustavo Bragança
* Gyanendra Shukla
* Hannes Breytenbach
* Hans Moritz Günther
* Harry Ferguson
* Helen Sherwood-Taylor
* Himanshu Pathak
* Hugo Buddelmeijer
* Humna Awan
* Ilya Kamenshchikov
* Inada Naoki
* J. Goutin
* J. Xavier Prochaska
* JC Hsu
* Jake VanderPlas
* Jakob Maljaars
* James Davies
* James Dearman
* James Noss
* James Taylor
* James Tocknell
* James Turner
* Jan Skowron
* Jane Rigby
* Jani Šumak
* Javier Pascual Granado
* Jean Connelly
* Jeff Taylor
* Jeffrey McBeth
* Jero Bado
* Jerry Ma
* Joanna Power
* Joe Hunkeler
* Joe Lyman
* Joe Philip Ninan
* John Fisher
* John Parejko
* Johnny Greco
* Jonas Große Sundrup
* Jonathan Eisenhamer
* Jonathan Foster
* Jonathan Sick
* Jonathan Whitmore
* Jörg Dietrich
* Jose Sabater
* Joseph Jon Booker
* Joseph Long
* Joseph Ryan
* Joseph Schlitz
* José Sabater Montes
* Juan Luis Cano Rodríguez
* Juanjo Bazán
* Julien Woillez
* Jurien Huisman
* Kacper Kowalik
* Karan Grover
* Karl Gordon
* Karl Vyhmeister
* Karl Wessel
* Katrin Leinweber
* Kelle Cruz
* Kevin Gullikson
* Kevin Sooley
* Kewei Li
* Kieran Leschinski
* Kirill Tchernyshyov
* Kris Stern
* Kristin Berry
* Kyle Barbary
* Kyle Oman
* Larry Bradley
* Laura Hayes
* Laura Watkins
* Lauren Glattly
* Leah Fulmer
* Lee Spitler
* Lehman Garrison
* Léni Gauffier
* Lennard Kiehl
* Leo Singer
* Leonardo Ferreira
* Lia Corrales
* Lingyi Hu
* Lisa Martin
* Lisa Walter
* Ludwig Schwardt
* Luigi Paioro
* Luke G. Bouma
* Luke Kelley
* M Atakan Gürkan
* M S R Dinesh
* Mabry Cervin
* Madhura Parikh
* Magali Mebsout
* Maik Nijhuis
* Manas Satish Bedmutha
* Maneesh Yadav
* Mangala Gowri Krishnamoorthy
* Manish Biswas
* Manodeep Sinha
* Mark Fardal
* Mark Taylor
* Marten van Kerkwijk
* Martin Glatzle
* Matej Stuchlik
* Mathieu Servillat
* Matt Davis
* Matteo Bachetti
* Matthew Bourque
* Matthew Brett
* Matthew Craig
* Matthew Petroff
* Matthew Turk
* Matthias Bussonnier
* Mavani Bhautik
* Max Silbiger
* Max Voronkov
* Maximilian Nöthe
* Médéric Boquien
* Megan Sosey
* Michael Droettboom
* Michael Hirsch
* Michael Hoenig
* Michael Lindner-D'Addario
* Michael Mueller
* Michael Seifert
* Michael Wood-Vasey
* Michael Zhang
* Michele Costa
* Michele Mastropietro
* Miguel de Val-Borro
* Mihai Cara
* Mike Alexandersen
* Mike McCarty
* Mikhail Minin
* Mikołaj
* Miruna Oprescu
* Moataz Hisham
* Mohan Agrawal
* Molly Peeples
* Nabil Freij
* Nadia Dencheva
* Nathanial Hendler
* Nathaniel Starkman
* Neal McBurnett
* Neil Crighton
* Neil Parley
* Nicholas Earl
* Nicholas S. Kern
* Nicholas Saunders
* Nick Lloyd
* Nick Murphy
* Nicolas Tessore
* Nikita Saxena
* Nikita Tewary
* Nimit Bhardwaj
* Noah Zuckman
* Nora Luetzgendorf
* Ole Streicher
* Orion Poplawski
* Param Patidar
* Parikshit Sakurikar
* Patricio Rojo
* Patti Carroll
* Paul Barrett
* Paul Hirst
* Paul Huwe
* Paul Price
* Paul Sladen
* Pauline Barmby
* Perry Greenfield
* Peter Cock
* Peter Teuben
* Peter Yoachim
* Pey Lian Lim
* Prasanth Nair
* Pratik Patel
* Pritish Chakraborty
* Pushkar Kopparla
* Ralf Gommers
* Rashid Khan
* Rasmus Handberg
* Ray Plante
* Régis Terrier
* Ricardo Fonseca
* Ricardo Ogando
* Richard R
* Ricky O'Steen
* Rik van Lieshout
* Ritiek Malhotra
* Ritwick DSouza
* Roban Hultman Kramer
* Robel Geda
* Robert Cross
* Rocio Kiman
* Rohan Rajpal
* Rohit Kapoor
* Rohit Patil
* Roman Tolesnikov
* Rui Xue
* Ryan Abernathey
* Ryan Cooke
* Ryan Fox
* Sadie Bartholomew
* Sam Lee
* Sam Verstocken
* Samuel Brice
* Sanjeev Dubey
* Sara Ogaz
* Sarah Kendrew
* Sashank Mishra
* Saurav Sachidanand
* Scott Thomas
* Semyeong Oh
* Serge Montagnac
* Sergio Pascual
* SF Graves
* Shailesh Ahuja
* Shankar Kulumani
* Shantanu Srivastava
* Shilpi Jain
* Shivan Sornarajah
* Shivansh Mishra
* Shresth Verma
* Shreyas Bapat
* Sigurd Næss
* Simon Conseil
* Simon Gibbons
* Simon Liedtke
* Simon Torres
* Sourabh Cheedella
* Srikrishna Sekhar
* Stefan Becker
* Stefan Nelson
* Stephen Portillo
* Steve Crawford
* Steve Guest
* Steven Bamford
* Stuart Littlefair
* Stuart Mumford
* Sudheesh Singanamalla
* Sushobhana Patra
* Suyog Garg
* Swapnil Sharma
* T. Carl Beery
* Tanuj Rastogi
* Thomas Erben
* Thomas Robitaille
* Thompson Le Blanc
* Tiffany Jansen
* Tim Gates
* Tim Jenness
* Tim Plummer
* Tito Dal Canton
* Tom Aldcroft
* Tom Donaldson
* Tom J Wilson
* Tom Kooij
* Tomas Babej
* Tyler Finethy
* VSN Reddy Janga
* Vatsala Swaroop
* Victoria Dye
* Vinayak Mehta
* Vishnunarayan K I
* Vital Fernández
* Víctor Terrón
* Víctor Zabalza
* Wilfred Tyler Gee
* William Jamieson
* Wolfgang Kerzendorf
* Yannick Copin
* Yash Kumar
* Yash Sharma
* Yingqi Ying
* Zac Hatfield-Dodds
* Zach Edwards
* Zachary Kurtz
* Zeljko Ivezic
* Zlatan Vasović
* Zé Vinicius

Other Credits
=============

* Kyle Barbary for designing the Astropy logos and documentation themes.
* Andrew Pontzen and the `pynbody <https://github.com/pynbody/pynbody>`_ team
  (For code that grew into :mod:`astropy.units`)
* Everyone on the `astropy-dev mailing list`_ and the `Astropy mailing list`_
  for contributing to many discussions and decisions!

(If you have contributed to the ``astropy`` core package and your name is missing,
please send an email to the coordinators, or
`open a pull request for this page <https://github.com/astropy/astropy/edit/main/docs/credits.rst>`_
in the `astropy repository <https://github.com/astropy/astropy>`_)

For how to acknowledge Astropy, please see `the Acknowledging or Citing Astropy page <https://www.astropy.org/acknowledging.html>`_.
